@@ -10,10 +10,16 @@ use ckb_verification_traits::Switch;
 use std::sync::Arc;
 
 pub fn replay(args: ReplayArgs, async_handle: Handle) -> Result<(), ExitCode> {
-    let shared_builder = SharedBuilder::new(&args.config.db, None, async_handle.clone())?;
+    let shared_builder = SharedBuilder::new(
+        &args.config.bin_name,
+        args.config.root_dir.as_path(),
+        &args.config.db,
+        None,
+        async_handle.clone(),
+    )?;
     let (shared, _) = shared_builder
         .consensus(args.consensus.clone())
-        .tx_pool_config(args.config.tx_pool)
+        .tx_pool_config(args.config.tx_pool.clone())
         .build()?;
 
     if !args.tmp_target.is_dir() {
@@ -31,7 +37,13 @@ pub fn replay(args: ReplayArgs, async_handle: Handle) -> Result<(), ExitCode> {
         let mut tmp_db_config = args.config.db.clone();
         tmp_db_config.path = tmp_db_dir.path().to_path_buf();
 
-        let shared_builder = SharedBuilder::new(&tmp_db_config, None, async_handle)?;
+        let shared_builder = SharedBuilder::new(
+            &args.config.bin_name,
+            args.config.root_dir.as_path(),
+            &tmp_db_config,
+            None,
+            async_handle,
+        )?;
         let (tmp_shared, mut pack) = shared_builder
             .consensus(args.consensus)
             .tx_pool_config(args.config.tx_pool)
@@ -62,7 +74,7 @@ fn profile(shared: Shared, mut chain: ChainService, from: Option<u64>, to: Optio
     println!("start profiling, re-process blocks {}..{}:", from, to);
     let now = std::time::Instant::now();
     let tx_count = process_range_block(&shared, &mut chain, from..=to);
-    let duration = now.elapsed();
+    let duration = std::time::Instant::now().saturating_duration_since(now);
     println!(
         "end profiling, duration {:?} txs {} tps {}",
         duration,
